# -*- coding: utf-8 -*-
"""Module for the command line interface."""
from .family import cmd_family
from .install import cmd_install, cmd_install_family, cmd_install_pseudo_dojo, cmd_install_sssp
from .list import cmd_list
from .root import cmd_root
